Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Input ¶
type Input interface {
Next() bool // Next returns true if there is a reply to Get
Get() json.RawMessage // Get the current reply
Error() error // Error returns the non-nil error if the iteration broke
}
Input object, "sort of" iterable object that allows iteration. you can iterate over this with a loop like:
for r.Next() {
current := r.Get()
}
if r.Error() != nil {
iteration ended with error
}
Click to show internal directories.
Click to hide internal directories.